==> haskell-interpolate-0.2.0-83-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: interpolate
version: 0.2.0
id: interpolate-0.2.0-npuYU4mrsQBftdkxgW1XV
key: interpolate-0.2.0-npuYU4mrsQBftdkxgW1XV
license: MIT
copyright: (c) 2013-2015 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: https://github.com/sol/interpolate#readme
synopsis: String interpolation done right
description:
    String interpolation done right
category: Data, Text
abi: 9200d1e6f61891dcd7b4c44a0f149563
exposed: True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.IsString
    Data.String.Interpolate.Util
hidden-modules: Data.String.Interpolate.Compat
                Data.String.Interpolate.Internal.Util Data.String.Interpolate.Parse
                Paths_interpolate
import-dirs: /usr/lib/ghc-8.6.5/site-local/interpolate-0.2.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/interpolate-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/interpolate-0.2.0
hs-libraries: HSinterpolate-0.2.0-npuYU4mrsQBftdkxgW1XV
depends:
    base-4.12.0.0 haskell-src-meta-0.8.2-5NagI6cnZBXEPFJzXxgPmf
    template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-interpolate/html/interpolate.haddock
haddock-html: /usr/share/doc/haskell-interpolate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-interpolate-0.2.0-84-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: interpolate
version: 0.2.0
id: interpolate-0.2.0-7S3viX2vyRA4u2N4nKDaT6
key: interpolate-0.2.0-7S3viX2vyRA4u2N4nKDaT6
license: MIT
copyright: (c) 2013-2015 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: https://github.com/sol/interpolate#readme
synopsis: String interpolation done right
description:
    String interpolation done right
category: Data, Text
abi: 7acdac2bd89c44658a30cf0cb1022602
exposed: True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.IsString
    Data.String.Interpolate.Util
hidden-modules: Data.String.Interpolate.Compat
                Data.String.Interpolate.Internal.Util Data.String.Interpolate.Parse
                Paths_interpolate
import-dirs: /usr/lib/ghc-8.6.5/site-local/interpolate-0.2.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/interpolate-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/interpolate-0.2.0
hs-libraries: HSinterpolate-0.2.0-7S3viX2vyRA4u2N4nKDaT6
depends:
    base-4.12.0.0 haskell-src-meta-0.8.2-DORzvGt0MI4uppYtSMBiU
    template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-interpolate/html/interpolate.haddock
haddock-html: /usr/share/doc/haskell-interpolate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
